@@ -1,7 +1,7 @@
-import numpy as np
-import pandas as pd
-from scipy import spatial
 from SpatialCluster.utils.data_format import data_format, position_data_format
+from scipy import spatial
+import pandas as pd
+import numpy as np
 
 def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400], max_neighbours=[200, 500, 1000], weight_mode="Simple", keep_original_value=True, smoothing=1e-08, normalize=True, leafsize=10):
 
@@ -74,11 +74,4 @@ def rings(features_X, features_position, criteria="k", max_radios=[200, 300, 400
             for f_index, feature in enumerate(features_X.columns):
                 final_features_df[f"{feature}_{original_radios[i]}m{k}nb"] = features_array[f_index]
         features_X = final_features_df
-    return features_X
-
-
-"""
-Revisar promedio de vecinos para los anillos
-Decidir si usar metros o no (ahora está en grados ?)
-
-"""
\ No newline at end of file
+    return features_X
\ No newline at end of file
